@@ -41,8 +41,6 @@
 
 #define KRUNNER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KRUNNER_NO_DEPRECATED) && !defined(KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KRUNNER_DEPRECATED
-#  define KRUNNER_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KRUNNER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KRUNNER_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -187,6 +185,12 @@
 #else
 #  define KRUNNER_DEPRECATED_VERSION_5_99(text)
 #endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x56a00
+#  define KRUNNER_DEPRECATED_VERSION_5_106(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_106(text)
+#endif
 #define KRUNNER_DEPRECATED_VERSION_5(minor, text)      KRUNNER_DEPRECATED_VERSION_5_##minor(text)
 #define KRUNNER_DEPRECATED_VERSION(major, minor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KRUNNER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
